Documentation
¶
Overview ¶
Package pathfilter provides utilities for filtering and sanitizing file paths to prevent path traversal.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FilterPath ¶
FilterPath removes any ".." components from the path to prevent path traversal. It cleans the path first, then removes any ".." components. If the path becomes empty or only contains "." after filtering, it returns ".".
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.